Module planner

Module planner 

Pure organization planning and path rendering.

Structs

CopyPlan
Filesystem operations produced by organization planning.
CopyTask
One file operation from a source path to a destination path.
OrganizationOptions
Options that control how source metadata becomes destination paths.

Constants

DEFAULT_TEMPLATE
Default destination template used by the CLI.

Functions

build_copy_plan
Builds copy tasks from metadata without touching destination files.
sanitize_path_component
Sanitizes a metadata value before using it as one path component.