pub fn read_track_metadata(path: &Path) -> MtagResult<TrackMetadata>Expand description
Reads the tag metadata needed by the planner from one audio file.
Errors
Returns MtagError::ReadMetadata if Lofty cannot parse the file and
MtagError::MissingTags when the file contains no readable tag block.